type Card = {
  title: string;
  content: string;
  variant: "primary" | "secondary" | "accent" | "neutral";
};

type StatChange = {
  value: string;
  percentage: string;
  direction: "up" | "down";
};

type Stat = {
  title: string;
  value: string;
  change?: StatChange;
};

export const siteConfig = {
  name: "Atash Consulting",
  description: "Software Consulting based in Edmonton, Alberta",

  header: {
    logo: {
      text: "Atash Consulting",
      href: "/",
    },
    nav: [
      {
        text: "Home",
        href: "/",
      },
      {
        text: "Services",
        href: "/services",
      },
      {
        text: "Contact",
        href: "/contact",
      },
    ],
    cta: {
      text: "Get Started",
      href: "/contact",
    },
  },

  hero: {
    title: "Atash Consulting",
    description: "Software Consulting based in Edmonton, Alberta",
  },

  featureCards: {
    enabled: true,
    cards: [
      {
        title: "Web Development",
        content: "Functional, accessible, and beautiful websites.",
        variant: "primary",
      },
      {
        title: "Mobile App Development",
        content: "iOS, Android, and cross-platform mobile applications.",
        variant: "secondary",
      },
      {
        title: "DevOps",
        content: "Anything from CI/CD to end-to-end UI testing.",
        variant: "secondary",
      },
      {
        title: "IT Support Processes",
        content:
          "Providing expert technical support expertise, backed by over a decade of client support experience.",
        variant: "primary",
      },
    ] as Card[],
  },

  statistics: {
    enabled: true,
    title: "Company Statistics",
    stats: [
      {
        title: "Years of Experience",
        value: "10+",
      },
      {
        title: "Reviews",
        value: "5⭐️",
      },
    ] as Stat[],
  },

  contact: {
    title: "Contact Us",
    description: "Ready to get started? Reach out to us for a consultation.",
    cta: {
      text: "Get in Touch",
      href: "/contact",
      ariaLabel: "Contact us for consultation",
    },
  },
} as const;

export type SiteConfig = typeof siteConfig;
