import type { APIRoute } from "astro";
import nodemailer from "nodemailer";

export const prerender = false;

const transporter = nodemailer.createTransport({
  host: import.meta.env.SMTP_HOST,
  port: parseInt(import.meta.env.SMTP_PORT),
  secure: import.meta.env.SMTP_PORT === "465",
  auth: {
    user: import.meta.env.SMTP_USER,
    pass: import.meta.env.SMTP_PASS,
  },
});

export const POST: APIRoute = async ({ request }) => {
  try {
    const data = await request.json();
    const { email, message } = data;

    if (!email || !message) {
      return new Response(
        JSON.stringify({
          message: "Email and message are required",
        }),
        { status: 400 },
      );
    }

    await transporter.sendMail({
      from: import.meta.env.FROM_EMAIL,
      to: [import.meta.env.TO_EMAIL],
      subject: `New Contact Form Submission from ${email}`,
      text: message,
      html: `
                <h2>New Contact Form Submission</h2>
                <p><strong>From:</strong> ${email}</p>
                <p><strong>Message:</strong></p>
                <p>${message.replace(/\n/g, "<br>")}</p>
            `,
    });

    return new Response(
      JSON.stringify({
        message: "Email sent successfully",
      }),
      { status: 200 },
    );
  } catch (error) {
    console.error("Error sending email:", error);
    return new Response(
      JSON.stringify({
        message: "Error sending email",
      }),
      { status: 500 },
    );
  }
};
